==> aria2-0.8.1.tar.bz2: aria2-0.8.1/src/HttpProxyRequestCommand.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "HttpProxyRequestCommand.h"
#include "HttpConnection.h"
#include "HttpProxyResponseCommand.h"

HttpProxyRequestCommand::HttpProxyRequestCommand(int cuid, Request* req,
						 DownloadEngine* e,
						 const SocketHandle& s)
  :AbstractCommand(cuid, req, e, s) {
  disableReadCheckSocket();
  setWriteCheckSocket(socket);
}

HttpProxyRequestCommand::~HttpProxyRequestCommand() {}

bool HttpProxyRequestCommand::executeInternal(Segment& segment) {
  socket->setBlockingMode();
  HttpConnection httpConnection(cuid, socket, req, e->option);
  httpConnection.sendProxyRequest();

  HttpProxyResponseCommand* command = new HttpProxyResponseCommand(cuid, req, e, socket);
  e->commands.push_back(command);
  return true;
}

==> aria2-1.25.0.tar.bz2: aria2-1.25.0/src/HttpProxyRequestCommand.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "HttpProxyRequestCommand.h"
#include "HttpProxyResponseCommand.h"
#include "Request.h"
#include "SocketCore.h"
#include "SocketRecvBuffer.h"
#include "a2functional.h"

namespace aria2 {

HttpProxyRequestCommand::HttpProxyRequestCommand(
    cuid_t cuid, const std::shared_ptr<Request>& req,
    const std::shared_ptr<FileEntry>& fileEntry, RequestGroup* requestGroup,
    DownloadEngine* e, const std::shared_ptr<Request>& proxyRequest,
    const std::shared_ptr<SocketCore>& s)
    : AbstractProxyRequestCommand(cuid, req, fileEntry, requestGroup, e,
                                  proxyRequest, s)
{
}

HttpProxyRequestCommand::~HttpProxyRequestCommand() {}

std::unique_ptr<Command> HttpProxyRequestCommand::getNextCommand()
{
  return make_unique<HttpProxyResponseCommand>(
      getCuid(), getRequest(), getFileEntry(), getRequestGroup(),
      getHttpConnection(), getDownloadEngine(), getSocket());
}

} // namespace aria2
